@@ -14,7 +14,8 @@ from .download import download
 from .url_handler import epHandler, videourl
 from . import config
 from .query import query
-from .player import start_player
-from .misc import entry, get_anime_info
+from .player import get_player
+from .misc import Entry, get_anime_info
 from .seasonal import Seasonal
 from .history import history
+
